#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filemanip
version:              0.3.6.3
visibility:           public
id:                   filemanip-0.3.6.3-7qJFZokoCrpBl5cyl8KEGq
key:                  filemanip-0.3.6.3-7qJFZokoCrpBl5cyl8KEGq
license:              BSD-3-Clause
maintainer:           Bryan O'\''Sullivan
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/filemanip
synopsis:             Expressive file and directory manipulation for Haskell.
description:
    A Haskell library for working with files and directories.
    Includes code for pattern matching, finding files,
    modifying file contents, and more.

category:             System
abi:                  305d1c8b342c97544fdea7c7b9b33732
exposed:              True
exposed-modules:
    System.FilePath.Find System.FilePath.Glob
    System.FilePath.GlobPattern System.FilePath.Manip

import-dirs:          /usr/lib/ghc-9.6.6/site-local/filemanip-0.3.6.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/filemanip-0.3.6.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/filemanip-0.3.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filemanip
hs-libraries:         HSfilemanip-0.3.6.3-7qJFZokoCrpBl5cyl8KEGq
depends:
    base-4.18.2.1 bytestring-0.11.5.3 directory-1.3.8.5
    filepath-1.4.300.1 mtl-2.3.1
    unix-compat-0.7.4.1-CNHdcuBo4WyE8NnkOFSrdm

haddock-interfaces:   /usr/share/doc/haskell-filemanip/html/filemanip.haddock
haddock-html:         /usr/share/doc/haskell-filemanip/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

